import request from '@/utils/request'

/**
 * 分页查询实施列表数据
 * @param data
 * @returns {*}
 */
export function getEnforcesByPage(data){
  return request({
    url: '/enforce/getEnforcesByPage',
    method: 'post',
    data: data
  })
}

/**
 * 添加实施项目
 * @param data
 * @returns {*}
 */
export function addEnforce(data) {
    return request({
      url: '/enforce/addEnForce',
      method: 'post',
      data : data
    })
}

/**
 * 删除实施项目
 * @param id
 * @returns {*}
 */
export function deleteEnforce(id) {
    return request({
      url: '/enforce/delete?id='+id,
      method: 'get'
    })
}

/**
 * 获取医院信息列表
 */
export function getHosInfos(){
    return request({
      url: '/enforce/getHosInfos',
      method : 'get'
    })
}

/**
 * 获取所属系统列表
 * @returns {*}
 */
export function getHsystems(){
  return request({
    url: '/enforce/getHsystems',
    method : 'get'
  })
}

/**
 * 启动实施流程
 * @param data
 * @returns {*}
 */
export  function startEnforceFlow(data){
  return request({
    url: '/enforce/startEnforceFlow',
    method : 'post',
    data: data
  })
}

/**
 * 获取个人任务办理列表
 * @returns {*}
 */
export  function getPersonalTaskList(){
  return request({
    url: '/enforce/getPersonalTaskList',
    method : 'post'
  })
}

/**
 * 点击完成个人任务
 * @param data
 * @returns {*}
 */
export function completeTask(data){
  return request({
    url:'/enforce/completeTask',
    method:'post',
    data:data
  })
}

/**
 * 查看流程明细
 * @param id
 * @returns {*}
 */
export  function getEnforceFlowsByEnforceId(id){
  return request({
    url:'/enforce/getEnforceFlowsByEnforceId?id='+id,
    method: 'get'
  })
}

/**
 * 根据流程id及其步骤查询详情
 * @param id
 * @param step
 * @returns {*}
 */
export function getEnforceFlowsByEnforceIdAndStep(id, step){
  return request({
    url:'/enforce/getEnforceFlowsByEnforceIdAndStep?id='+id+"&step="+step,
    method: 'get'
  })
}

/**
 * 根据流程id 获取当前流程上传的文件列表
 * @param id
 * @returns {*}
 */
export function getEnforceFlowFiles(id){
  return request({
    url:'/enforceFlow/getEnforceFlowFiles?id=' + id,
    method: 'get'
  })
}

/**
 * 个人任务Map
 * @param user
 * @returns {*}
 */
export function getPersonalTaskMap(user){
  return request({
    url:'/enforce/getPersonalTaskMap?user='+encodeURIComponent(user),
    method: 'get'
  })
}

/**
 * 手动更新流程表单信息
 * @param data
 * @returns {*}
 */
export function updateEnforceFlow(data){
  return request({
    url:'/enforceFlow/updateEnforceFlow',
    method:'post',
    data:data
  })
}

/**
 *
 * 添加系统字段类型数据
 */
export function insertSysDictData(data){
  return request({
    url:'/system/dict/type/insertSysDictData',
    method:'post',
    data:data
  })
}



