import request from '@/utils/request'
import download from '@/utils/download'

//添加会议
export function addMeeting(data){
  return request({
    url: '/meeting/add',
    method: 'post',
    data: data
  })
}

/**
 * 分页查询会议信息
 * @param data
 * @returns {*}
 */
export function getMeetingsByPage(data){
  return request({
    url: '/meeting/getMeetingsByPage',
    method: 'post',
    data:data
  })
}

/**
 * 删除会议信息
 * @param id
 * @returns {*}
 */
export function deleteMeeting(id){
  return request({
    url: '/meeting/delete?id='+id,
    method: 'get'
  })
}

/**
 * 获取会议类型为周例会列表
 * @returns {*}
 */
export function list(){
  return request({
    url: '/meeting/list',
    method: 'get'
  })
}

/**
 * 根据id获取会议明细
 * @param id
 * @returns {*}
 */
export function getMeetingDetailsById(id){
  return request({
    url: '/meeting/getMeetingDetailsById?id='+id,
    method: 'get'
  })
}

/**
 * 根据id 删除会议内容
 * @param id
 * @returns {*}
 */
export function deleteMeetingContentById(id){
  return request({
    url: '/meeting/deleteMeetingContentById?id='+id,
    method: 'get'
  })
}

/**
 * 保存会议建议
 * @param data
 * @returns {*}
 */
export function saveMeetingOptionss(data){
  return request({
    url: '/meeting/saveMeetingOptionss',
    method: 'post',
    data: data
  })
}

/**
 * 点击确认会议--生成任务报告
 * @param id
 * @returns {*}
 */
export function confirmMeetings(id){
  return request({
    url: '/meeting/confirmMeeting?id=' + id,
    method: 'get'
  })
}

/**
 * 获取待办会议列表
 * @returns {AxiosPromise}
 */
export function getTodoMeetings(){
  return request({
    url: '/meeting/getTodoMeetings',
    method: 'get'
  })
}

export function downloadPdf(meetingId,weeks){
  return download({
    url: '/meeting/download?meetingId='+meetingId+'&weeks='+weeks,
    method: 'get',
    responseType: 'blob',
  })
}

/**
 * 通过所属周 查询周报记录信息
 * @param meetingId
 * @param weeks
 * @returns {*}
 */
export function getWeeksRecordsByWeeks(meetingId,weeks){
  return request({
    url: '/meeting/getWeeksRecordsByWeeks?meetingId='+meetingId+'&weeks='+weeks,
    method : 'get'
  })
}

/**
 * 工作评分评论
 * @param data
 * @returns {*}
 */
export function workComments(data){
  return request({
    url: '/meeting/workComment',
    method: 'post',
    data: data
  })
}

/**
 * 会议信息更改
 * @param data
 * @returns {*}
 */
export function workMeetingsUpdates(data){
  return request({
    url: '/meeting/workMeetingsUpdate',
    method: 'post',
    data: data
  })
}

/**
 * 获取周会会议信息
 * @returns {*}
 */
export function getMeetingByWeekss(){
  return request({
    url: '/meeting/getMeetingByWeeks',
    method: 'get'
  })
}

/**
 * 根据任务id 获取任务反馈备注
 * @param id
 * @returns {*}
 */
export function getTaskScheduleRemark(id){
  return request({
    url: '/workPlan/getTaskScheduleRemark?taskId='+id,
    method: 'get'
  })
}

/**
 * 周会确认
 * @param meetingId
 * @param weeks
 * @returns {*}
 */
export function weekMeetingConfirms(meetingId,weeks){
  return request({
    url: '/meeting/weekMeetingConfirm?meetingId='+meetingId+"&weeks="+weeks,
    method: 'get'
  })
}

/**
 * 开启会议
 * @param id
 * @returns {*}
 */
export function startMeetingById(id){
  return request({
    url: '/meeting/startMeeting?meetingId='+id,
    method: 'get'
  })
}

/**
 * 会议权限查询
 * @param id
 * @returns {*}
 */
export function meetingAuthById(id){
  return request({
    url: '/meeting/meetingAuth?meetingId='+id,
    method: 'get'
  })
}

/**
 * 验证会议删除权限
 * @param id
 * @returns {*}
 */
export function meetingDeleteAuth(id){
  return request({
    url: '/meeting/meetingDeleteAuth?meetingId='+id,
    method: 'get'
  })
}

//查看会议数量
export function getTodoMeetinStatistics(){
  return request({
    url: '/meeting/getTodoMeetinStatistics',
    method: 'get'
  })
}

/**
 * 手动结束会议功能
 * @param id
 * @returns {*}
 */
export function endMeeting(id){
  return request({
    url: '/meeting/endMeeting?meetingId='+id,
    method: 'get'
  })
}


/**
 * 编辑会议内容
 * @param data
 * @returns {*}
 */
export function editMeetingContent(data){
  return request({
    url: '/meeting/editMeetingContent',
    method: 'post',
    data: data
  })
}

/**
 * 根据会议ID获取会议内容
 * @param id
 * @returns {*}
 */
export function getMeetingContentsByMeetingId(id){
  return request({
    url: '/meeting/getMeetingContentsByMeetingId?meetingId='+id,
    method: 'get'
  })
}

/**
 * 根据id导出会议通知
 * @param id
 */
export function exportOutMeetingNotice(id){
  return download({
    url: '/meeting/exportOutMeetingNotice?meetingId='+id,
    method: 'get',
    responseType: 'blob',
  })
}

/**
 * 编辑会议基础信息
 * @param data
 * @returns {*}
 */
export function editMeeting(data){
  return request({
    url: '/meeting/editMeeting',
    method: 'post',
    data: data
  })
}

/**
 * 确认其他会议、实施会议方法--扩展
 * @param data
 * @returns {*}
 */
export function confirmOthersMeeting(data){
  return request({
    url: '/meeting/confirmOtherMeeting',
    method: 'post',
    data: data
  })
}

/**
 * 增加获取按钮会议结果权限是否展示
 * @param data
 * @returns {*}
 */
export function getMeetingConfirmBtnFlag(data){
  return request({
    url: '/meeting/getMeetingConfirmBtnFlag',
    method: 'post',
    data: data
  })
}
