import request from '@/utils/request'
import download from '@/utils/download'

/**
 * 根据年份获取日期列表数据
 * @param year
 * @returns {*}
 */
export function getDateListByYear(year) {
  return request({
    url: '/performanceDateSet/getDateListByYear?year=' + year,
    method: 'get'
  })
}

/**
 * 获取日期集合列表数据
 * @returns {*}
 */
export function getDateDataList() {
  return request({
    url: '/performanceDateSet/getDateDataList',
    method: 'get'
  })
}

/**
 * 添加评分设置
 * @param data
 * @returns {*}
 */
export function addPerformanceScoreSet(data) {
  return request({
    url: "/performanceScoreSet/addPerformanceScoreSet",
    method: "POST",
    data: data
  })
}

/**
 * 编辑绩效评分
 * @param data
 * @returns {*}
 */
export function editPerformanceScore(data) {
  return request({
    url: "/performanceScore/editPerformanceScore",
    method: "POST",
    data: data
  })
}

/**
 * 获取绩效评分列表数据
 * @param data
 * @returns {*}
 */
export function getPerformanceScoreList(data) {
  return request({
    url: "/performanceScore/getPerformanceScoreList",
    method: "POST",
    data: data
  })
}

/**
 * 导出绩效评分
 * @param data
 * @returns {AxiosPromise}
 */
export function exportPerformanceScore(data) {
  return download({
    url: '/performanceScore/export',
    method: 'get',
    responseType: 'blob',
    params: data
  })
}

export function delScoreSet(scoreSetId) {
  return request({
    url: '/performanceScoreSet/' + scoreSetId,
    method: 'delete'
  })
}


export function updateScoreSet(data) {
  return request({
    url: '/performanceScoreSet/',
    method: 'put',
    data: data
  })
}
