import request from '@/utils/request'


// 查询用户列表
export function listUser(query) {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  })
}

// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/system/user/' + userId,
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  return request({
    url: '/system/user',
    method: 'post',
    data: data
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/system/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/system/user/' + userId,
    method: 'delete'
  })
}

// 用户密码重置
export function resetUserPwd(data) {
  return request({
    url: '/system/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(data) {
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    data: data
  })
}


// 查询部门下拉树结构
export function deptTreeSelect() {
  return request({
    url: '/system/dept/deptTree',
    method: 'get'
  })
}

// 查询部门员工树结构
export function getDeptUserTree(deptId) {
  return request({
    url: '/system/user/getDeptUserTree/' + deptId,
    method: 'get'
  })
}

// 用户修改密码
export function updateUserPwd(oldPassword, newPassword) {
  const data = {
    oldPassword,
    newPassword
  }
  return request({
    url: '/system/user/updateUserPwd',
    method: 'put',
    params: data
  })
}

export function syncUser() {
  return request({
    url: '/system/user/syncUser' ,
    method: 'get'
  })
}

// 根据用户ID查询用户权限（菜单按钮ID）
export function getPermissionByUserId(userId) {
  return request({
    url: '/system/role/getPermissionByUserId/' + userId,
    method: 'get'
  })
}

// 查询具有审核权限的用户
export function getAuditUsers() {
  return request({
    url: '/system/user/auditUsers',
    method: 'get'
  })
}
