import Vue from 'vue'

import 'normalize.css/normalize.css' // A modern alternative to CSS resets

import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import './assets/styles/element-variables.scss'
import '@/assets/styles/index.scss' // global css
// import '@/assets/styles/ruoyi.scss' // ruoyi css

import locale from 'element-ui/lib/locale/lang/en' // lang i18n
import zh from 'element-ui/lib/locale/lang/zh-CN' // lang i18n
import directive from './directive'
import auth from './plugins/auth'
import '@/styles/index.scss' // global css
import '@/assets/styles/ruoyi.scss'

import App from './App'
import store from './store'
import router from './router'

import '@/icons' // icon
import '@/permission' // permission control
import { getDictData } from "@/api/system/dict";
// 字典标签组件
import DictTag from '@/components/DictTag'
// 字典数据组件
import DictData from '@/components/DictData'
import {
  parseTime,
  resetForm,
  addDateRange,
  selectDictLabel,
  selectDictLabels,
  handleTree,
  getMonthDate
} from "@/utils/common";
//时间转换主键
import * as moment from 'moment'
import ElTableInfiniteScroll from 'el-table-infinite-scroll'

Vue.prototype.getDicts = getDictData

Vue.prototype.$moment = moment
Vue.prototype.parseTime = parseTime
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.selectDictLabels = selectDictLabels
Vue.prototype.handleTree = handleTree
Vue.prototype.getMonthDate = getMonthDate

Vue.component('DictTag', DictTag)


// 修改 el-dialog 默认点击遮照为不关闭
ElementUI.Dialog.props.closeOnClickModal.default = false

Vue.use(ElementUI, {
  locale: zh,
  size: 'mini' // set element-ui default size
})
// set ElementUI lang to EN
// Vue.use(ElementUI, { locale })
// 如果想要中文版 element-ui，按如下方式声明
// Vue.use(ElementUI, {locale: zh})
Vue.use(directive)
Vue.directive("el-table-infinite-scroll", ElTableInfiniteScroll);
Vue.use(auth)
DictData.install()


Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
