import DateUtil from "@/utils/date";

const statusMap = {
  '0': {name: '待查看', type: 'info'},
  '1': {name: '未开始', type: 'info'},
  '2': {name: '进行中', type: ''},
  '3': {name: '延期', type: 'danger'},
  '4': {name: '完成', type: 'success'},
  '5': {name: '终止', type: 'warning'},
  '6': {name: '待审核', type: 'warning'}
}

const fieldMap = {
  'taskName': '任务名称',
  'projectId': '所属项目',
  'beginDate': '开始日期',
  'endDate': '结束日期',
  'executor': '执行人',
  'fileUrl': '附件',
  'description': '描述',
  'priority': '优先级',
  'status': '状态',
}


export default {

  data() {
    return {
      statusMap: statusMap,
      cellColorMap: {
        '1': '#fefeff',
        '2': '#a6a9ad',
        '3': '#f56c6c',
        '4': '#67c23a',
        '5': '#e6a23c',
        '6': '#e1b111'
      },
      priorityColorMap: {
        '1': '#fa8888',
        '2': '#fb7fb7',
        '3': '#f4d66d',
        '4': '#40e0c3',
        '5': '#5dcfff',
      },
      clickTimer: undefined,
    }
  },

  methods: {
    checkRichText(text) {
      if (!text) {
        return false
      }
      text = text.replaceAll('<p>', '').replaceAll('</p>', '').replaceAll('<br>', '').replaceAll('&nbsp;', '').trim();
      return text.length > 0 ? true : false
    },
    checkDates(startDate, endDate) {
      if (!startDate || !endDate) {
        return
      }
      if (DateUtil.unix(startDate) > DateUtil.unix(endDate)) {
        this.$message.warning("开始时间不能超过结束时间")
      }
    },
    getTaskPriority(priority) {
      let label = ''
      this.dict.type.task_priority.forEach(dict => {
        if (dict.value === priority) {
          label = dict.label
        }
      })
      return label
    },

    cellMouseEnter(row, column, cell, event) {
      if (column.property != 'taskName') {
        return
      }
      cell.style.color = '#306FB1';
      cell.style.cursor = 'pointer';
      cell.style.textDecoration = 'underline';
    },
    cellMouseLeave(row, column, cell, event) {
      if (column.property != 'taskName') {
        return
      }
      cell.style.color = '#606266';
      cell.style.textDecoration = 'none';
    },

    getFieldName(field) {
      return fieldMap[field]
    }
  }
}
